#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_mhi_interfaces.mhi_load_parameters import MHILoadParameters
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class MHIOpenAccess(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MHIOpenAccess
                | 
                | Interface representing a means to load data from the Hub into
                | V5.
                | 
                | DNBIAMHIOpenAccess is implemented on Application. Applications and CAA partners
                | should NOT implement this interface.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.mhi_open_access = com_object

    def connect_to_ppr_hub(self, i_username: str, i_password: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ConnectToPPRHub(CATBSTR iUsername,
                | CATBSTR iPassword)
                | 
                |     This method establishes a connection to the PPRHub
                | 
                |     Parameters:
                | 
                |         iUsername
                |             [in] User Login name 
                |         iPassword
                |             [in] User password 
                | 
                |     Returns:
                |         S_OK if connection established OK S_FALSE if connection is already
                |         established for user E_FAIL if connection could not be established

        :param str i_username:
        :param str i_password:
        :rtype: None
        """
        return self.mhi_open_access.ConnectToPPRHub(i_username, i_password)

    def create_load_parameters(self) -> MHILoadParameters:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateLoadParameters() As MHILoadParameters
                | 
                |     This method creates an object which will contain all the necessary
                |     information required for loading an object (and its structure) from a PPR Hub
                |     into V5
                | 
                |     Parameters:
                | 
                |         oLoadParameters
                |             [out] Interface to the created Load Parameters object
                |
                |     Returns:
                |         S_OK if object created ok and interface returned OK E_FAIL on error

        :rtype: MHILoadParameters
        """
        return MHILoadParameters(self.mhi_open_access.CreateLoadParameters())

    def load_from_ppr_hub(
            self,
            i_load_parameters: MHILoadParameters,
            i_create_default_window: bool,
            i_is_read_only: bool,
            o_error_messages: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func LoadFromPPRHub(MHILoadParameters iLoadParameters,
                | boolean iCreateDefaultWindow,
                | boolean iIsReadOnly,
                | CATSafeArrayVariant oErrorMessages) As Document
                | 
                |     This method loads an object (and it structure) from a PPR Hub project into
                |     V5 Note: All Tools->Options settings will be respected during the
                |     load
                | 
                |     Parameters:
                | 
                |         iLoadParameters
                |             [in] The object which contains all the necessary information for
                |             the load 
                |         iCreateDefaultWindow
                |             [in] Option to indicate whether a window needs to be created for
                |             the document or not If no window is created, then caller is responsible for
                |             life cycle of document 
                |         iIsReadOnly
                |             [in] Option to indicate if document is to loaded in read-only mode
                |             
                |         oLoadedDoc
                |             [out] The V5 document into which data from the Hub is loaded
                |             
                |         oErrorMessages
                |             [out] The list of message about invalid or insufficient agruments
                |             passed to the method 
                | 
                |     Returns:
                |         S_OK if everything ran OK E_FAIL on error

        :param MHILoadParameters i_load_parameters:
        :param bool i_create_default_window:
        :param bool i_is_read_only:
        :param tuple o_error_messages:
        :rtype: Document
        """
        return Document(
            self.mhi_open_access.LoadFromPPRHub(
                i_load_parameters.com_object,
                i_create_default_window,
                i_is_read_only,
                o_error_messages
            )
        )

    def set_environment_for_vbs_launch(
            self,
            i_obj_id: str,
            i_filter: str,
            i_parent_id: str,
            i_project_id: str,
            i_user_name: str,
            i_pwd: str,
            o_error_messages: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetEnvironmentForVBSLaunch(CATBSTR iObjId,
                | CATBSTR iFilter,
                | CATBSTR iParentId,
                | CATBSTR iProjectId,
                | CATBSTR iUserName,
                | CATBSTR iPwd,
                | CATSafeArrayVariant oErrorMessages)
                | 
                |     This method sets the environment required for Direct Launch Through given
                |     VB Script
                | 
                |     Parameters:
                | 
                |         iObjId
                |             [in] process object ECB ID. Which needs to be opened in DPM
                |             
                |         iFilter
                |             [in] selected Project filters 
                |         iParentId
                |             [in] parent object ECB ID 
                |         iProjectId
                |             [in] project ID 
                |         iUserName
                |             [in] user name to log-on to DPE 
                |         iPwd
                |             [in] password to log-on to DPE 
                |         oErrorMessages
                |             [out] error messages(if any) 
                | 
                |     Returns:
                |         S_OK if everything ran OK E_FAIL on error

        :param str i_obj_id:
        :param str i_filter:
        :param str i_parent_id:
        :param str i_project_id:
        :param str i_user_name:
        :param str i_pwd:
        :param tuple o_error_messages:
        :rtype: None
        """
        return self.mhi_open_access.SetEnvironmentForVBSLaunch(
            i_obj_id,
            i_filter,
            i_parent_id,
            i_project_id,
            i_user_name,
            i_pwd,
            o_error_messages
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_environment_for_vbs_launch'
        # # vba_code = """
        # # Public Function set_environment_for_vbs_launch(mhi_open_access)
        # #     Dim iObjId (2)
        # #     mhi_open_access.SetEnvironmentForVBSLaunch iObjId
        # #     set_environment_for_vbs_launch = iObjId
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MHIOpenAccess(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PertNode(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PertNode
                | 
                | This Interface represents a PertNode in the PERT Chart.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pert_node = com_object

    def get_location(self, xx: float, yy: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocation(double xx,
                | double yy)
                | 
                |     This method gets the Location of the PertNode in the PERT
                |     Chart
                | 
                |     Parameters:
                | 
                |         xx
                |             X Coordinate of the Location in the Pert Chart 
                |         yy
                |             Y Coordinate of the Location in the Pert Chart

        :param float xx:
        :param float yy:
        :rtype: None
        """
        return self.pert_node.GetLocation(xx, yy)

    def set_icon(self, i_file_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetIcon(CATBSTR iFileName)
                | 
                |     This method sets Icon for the PertNode in the PERT Chart
                | 
                |     Parameters:
                | 
                |         iFileName
                |             FileName of the Icon which includes full path

        :param str i_file_name:
        :rtype: None
        """
        return self.pert_node.SetIcon(i_file_name)

    def set_location(self, xx: float, yy: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocation(double xx,
                | double yy)
                | 
                |     This method place the PertNode in the PERT Chart at any location by
                |     specifying the X and Y Coordinates in the Grid.
                | 
                |     Parameters:
                | 
                |         xx
                |             X Coordinate of the Location in the Pert Chart 
                |         yy
                |             Y Coordinate of the Location in the Pert Chart

        :param float xx:
        :param float yy:
        :rtype: None
        """
        return self.pert_node.SetLocation(xx, yy)

    def __repr__(self):
        return f'PertNode(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Shot(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Shot
                | 
                | The interface to access a CATIAShot.
                | Role: A CATIAShot (or shot) is the base element that Sampled objects are
                | composed of. For example, when considering a Track, each recorded position is a
                | shot.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shot = com_object

    def append_abs_datas(self, i_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppendAbsDatas(CATSafeArrayVariant iPosition)
                | 
                |     Appends to the data related to the shot. Role: In certain cases, a shot
                |     contains more than one data item. The SetDatas method is used to store the
                |     first data item. This method is then used to specify any additional data
                |     items
                | 
                |     Parameters:
                | 
                |         iPosition
                |             An array of associated values to the shot. Please note that these
                |             values are absolute (relative to the world coordinate system), specifically to
                |             where the object started from.

        :param tuple i_position:
        :rtype: None
        """
        return self.shot.AppendAbsDatas(i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_abs_datas'
        # # vba_code = """
        # # Public Function append_abs_datas(shot)
        # #     Dim iPosition (2)
        # #     shot.AppendAbsDatas iPosition
        # #     append_abs_datas = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def append_datas(self, i_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppendDatas(CATSafeArrayVariant iPosition)
                | 
                |     Appends to the data related to the shot. Role: In certain cases, a shot
                |     contains more than one data item. The SetDatas method is used to store the
                |     first data item. This method is then used to specify any additional data
                |     items.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             An array of associated values to the shot. Please note that these
                |             values are relative to the position of object, specifically to where the object
                |             started from.

        :param tuple i_position:
        :rtype: None
        """
        return self.shot.AppendDatas(i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'append_datas'
        # # vba_code = """
        # # Public Function append_datas(shot)
        # #     Dim iPosition (2)
        # #     shot.AppendDatas iPosition
        # #     append_datas = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_abs_datas(self, i_index: int, o_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetAbsDatas(short iIndex,
                | CATSafeArrayVariant oPosition)
                | 
                |     Retrieves the data related to the shot. Role: To get the numerical
                |     information related to the shot. For example, for a Track, each shot
                |     corresponds to a position that is used when evaluating a defined trajectory.
                |     Please note that these values are absolute (relative to the world coordinate
                |     system), specifically to where the object started from.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             A shot can have more than one piece of data associated to it. The
                |             value of iIndex refers to which specific data item to retrieve. The legal
                |             values of iIndex correspond to the rank of the data item (that is the 0 for the
                |             first item, 1 for the second item). 
                | 
                |     Returns:
                |         An array of associated values to the shot.

        :param int i_index:
        :param tuple o_position:
        :rtype: None
        """
        return self.shot.GetAbsDatas(i_index, o_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_abs_datas'
        # # vba_code = """
        # # Public Function get_abs_datas(shot)
        # #     Dim iIndex (2)
        # #     shot.GetAbsDatas iIndex
        # #     get_abs_datas = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_datas(self, i_index: int, o_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDatas(short iIndex,
                | CATSafeArrayVariant oPosition)
                | 
                |     Retrieves the data related to the shot. Role: To get the numerical
                |     information related to the shot. For example, for a Track, each shot
                |     corresponds to a position that is used when evaluating a defined trajectory.
                |     Please note that these values are relative to the position of object,
                |     specifically to where the object started from.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             A shot can have more than one piece of data associated to it. The
                |             value value of iIndex refers to which specific data item to retrieve. The legal
                |             values of iIndex correspond to the rank of the data item (that is the 0 for the
                |             first item, 1 for the second item). 
                | 
                |     Returns:
                |         An array of associated values to the shot.

        :param int i_index:
        :param tuple o_position:
        :rtype: None
        """
        return self.shot.GetDatas(i_index, o_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_datas'
        # # vba_code = """
        # # Public Function get_datas(shot)
        # #     Dim iIndex (2)
        # #     shot.GetDatas iIndex
        # #     get_datas = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_duration(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDuration() As double
                | 
                |     Retrieves the duration (in terms of distance) associated to a shot. The
                |     duration of a shot is the amount of time needed to travel from the previous
                |     shot to the current shot. However, this method retrieves the distance of the
                |     current shot from that of the previous shot. It is left for the user to
                |     calculate the Time using distance/speed Formula. Some key things to note
                |     are:
                | 
                |         The first shot should have a duration of zero.
                |         The value of the duration is a positive real number. Hence, 0.454 &
                |         1345 are legal while -18 is not. 
                | 
                |     Parameters:
                | 
                |         oTime
                |             The duration (distance) of a shot.

        :rtype: float
        """
        return self.shot.GetDuration()

    def get_technological_datas(self, o_datas: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTechnologicalDatas(CATSafeArrayVariant oDatas)
                | 
                |     Retrieves all the data associated to the part.

        :param tuple o_datas:
        :rtype: None
        """
        return self.shot.GetTechnologicalDatas(o_datas)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_technological_datas'
        # # vba_code = """
        # # Public Function get_technological_datas(shot)
        # #     Dim oDatas (2)
        # #     shot.GetTechnologicalDatas oDatas
        # #     get_technological_datas = oDatas
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_abs_datas(self, i_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAbsDatas(CATSafeArrayVariant iPosition)
                | 
                |     Set the data related to the shot. Role: To set the numerical information
                |     related to the shot. For example, for a Track, each shot corresponds to a
                |     position that is used when evaluating a defined
                |     trajectory.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             An array of associated values to the shot. Please note that these
                |             values are absolute (relative to the world coordinate system), specifically to
                |             where the object started from.

        :param tuple i_position:
        :rtype: None
        """
        return self.shot.SetAbsDatas(i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_abs_datas'
        # # vba_code = """
        # # Public Function set_abs_datas(shot)
        # #     Dim iPosition (2)
        # #     shot.SetAbsDatas iPosition
        # #     set_abs_datas = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_datas(self, i_position: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDatas(CATSafeArrayVariant iPosition)
                | 
                |     Set the data related to the shot. Role: To set the numerical information
                |     related to the shot. For example, for a Track, each shot corresponds to a
                |     position that is used when evaluating a defined
                |     trajectory.
                | 
                |     Parameters:
                | 
                |         iPosition
                |             An array of associated values to the shot. Please note that these
                |             values are relative to the position of object, specifically to where the object
                |             started from.

        :param tuple i_position:
        :rtype: None
        """
        return self.shot.SetDatas(i_position)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_datas'
        # # vba_code = """
        # # Public Function set_datas(shot)
        # #     Dim iPosition (2)
        # #     shot.SetDatas iPosition
        # #     set_datas = iPosition
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_duration(self, i_duration: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDuration(double iDuration)
                | 
                |     Sets the duration (in terms of distance) associated to a shot. The duration
                |     of a shot is the amount of time needed to travel from the previous shot to the
                |     current shot. However, this method sets the distance of the current shot from
                |     that of the previous shot. It is left for the user to calculate the distance
                |     that needs to be set for the shot using the Time*Speed Formula. Some key things
                |     to note are:
                | 
                |         The first shot should have a duration of zero.
                |         The value of the duration is a positive real number. Hence, 0.454 &
                |         1345 are legal while -18 is not. 
                | 
                |     Parameters:
                | 
                |         oTime
                |             The duration (distance) of a shot.

        :param float i_duration:
        :rtype: None
        """
        return self.shot.SetDuration(i_duration)

    def set_technological_datas(self, i_datas: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTechnologicalDatas(CATSafeArrayVariant iDatas)
                | 
                |     Sets all the data associated to the part.

        :param tuple i_datas:
        :rtype: None
        """
        return self.shot.SetTechnologicalDatas(i_datas)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_technological_datas'
        # # vba_code = """
        # # Public Function set_technological_datas(shot)
        # #     Dim iDatas (2)
        # #     shot.SetTechnologicalDatas iDatas
        # #     set_technological_datas = iDatas
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'Shot(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DxfSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DxfSettingAtt
                | 
                | Interface dedicated to modify or read the current settings corresponding to the
                | DXF Data Exchange (used for DXF or DWG files)
                | 
                | Ensure consistency with the C++ interface to which the work is
                | delegated.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dxf_setting_att = com_object

    @property
    def export_blocks(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportBlocks() As CatDxfExportBlocksEnum (Read
                | Only)
                | 
                |     Get the value of the Export Blocks option. That value is only taken into
                |     account when the export mode is set to Semantic.
                | 
                |     Parameters:
                | 
                |         oExportBlocks
                |             Legal values: An available value of the enum
                |             CatDxfExportBlocksEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_export_blocks_enum
        :rtype: int
        """

        return self.dxf_setting_att.ExportBlocks

    @property
    def export_dimensions_as_dimensions(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportDimensionsAsDimensions() As boolean (Read
                | Only)
                | 
                |     Get the value of the Export Dimensions As Dimensions option. That value is
                |     only taken into account when the export mode is set to
                |     Semantic.
                | 
                |     Parameters:
                | 
                |         oExportDimension
                |             Legal values:
                |             TRUE : Export dimensions as dimensions.
                |             FALSE : Export dimensions as graphical block. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ExportDimensionsAsDimensions

    @property
    def export_layer_name(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportLayerName() As boolean (Read Only)
                | 
                |     Get the value of the Export Layer Name option. That value is only taken
                |     into account when the export mode is set to Semantic.
                | 
                |     Parameters:
                | 
                |         oExportLayerName
                |             Legal values:
                |             TRUE : Export Layer Name.
                |             FALSE : Export Layer Number. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ExportLayerName

    @property
    def export_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportMode() As CatDxfExportModeEnum (Read Only)
                | 
                |     Get the Export Mode option value.
                | 
                |     Parameters:
                | 
                |         oMode
                |             Legal values: An available value of the enum CatDxfExportModeEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_export_mode_enum
        :rtype: int
        """

        return self.dxf_setting_att.ExportMode

    @property
    def export_sheets(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportSheets() As CatDxfExportSheetsEnum (Read
                | Only)
                | 
                |     Get the Exported Sheets option value.
                | 
                |     Parameters:
                | 
                |         oSheets
                |             Legal values: An available value of the enum
                |             CatDxfExportSheetsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_export_sheets_enum
        :rtype: int
        """

        return self.dxf_setting_att.ExportSheets

    @property
    def export_version(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportVersion() As CatDxfExportVersionEnum (Read
                | Only)
                | 
                |     Get the Export Version option value.
                | 
                |     Parameters:
                | 
                |         oVersion
                |             Legal values: An available value of the enum
                |             CatDxfExportVersionEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_export_version_enum
        :rtype: int
        """

        return self.dxf_setting_att.ExportVersion

    @property
    def export_views_as_viewports(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExportViewsAsViewports() As boolean (Read Only)
                | 
                |     Get the value of the Export Views as Viewports option. That value is only
                |     taken into account when the export mode is set to
                |     Semantic.
                | 
                |     Parameters:
                | 
                |         oViewsAsViewports
                |             Legal values:
                |             TRUE : Export Views as Viewports enable.
                |             FALSE : Export Views as Viewports disable. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ExportViewsAsViewports

    @property
    def import_dft_standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDftStandard() As CATBSTR (Read Only)
                | 
                |     Get the name of the Drafting standard, which define the standard of the
                |     resulting CATDrawing file.
                | 
                |     Parameters:
                | 
                |         oDftStandard
                |             the CATBSTR corresponding to the Drafting standard.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: str
        """

        return self.dxf_setting_att.ImportDftStandard

    @property
    def import_dimensions(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDimensions() As CatDxfImportDimensionsEnum (Read
                | Only)
                | 
                |     Get the Import dimensions option value.
                | 
                |     Parameters:
                | 
                |         oDimensions
                |             Legal values: An available value of the enum
                |             CatDxfImportDimensionsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_import_dimensions_enum
        :rtype: int
        """

        return self.dxf_setting_att.ImportDimensions

    @property
    def import_dxf_standard(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportDxfStandard() As CATBSTR (Read Only)
                | 
                |     Get the name of the Dxf standard, which define the different mapping used
                |     at import.
                | 
                |     Parameters:
                | 
                |         oDxfStandard
                |             the CATBSTR corresponding to the Dxf standard. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: str
        """

        return self.dxf_setting_att.ImportDxfStandard

    @property
    def import_end_points(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportEndPoints() As CatDxfImportCreateEndPointsEnum (Read
                | Only)
                | 
                |     Get the Create End Points option value.
                | 
                |     Parameters:
                | 
                |         oEndPoints
                |             Legal values: An available value of the enum
                |             CatDxfImportCreateEndPointsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_import_create_end_points_enum
        :rtype: int
        """

        return self.dxf_setting_att.ImportEndPoints

    @property
    def import_keep_model_space(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportKeepModelSpace() As boolean (Read Only)
                | 
                |     Get the value of the Keep Model Space option.
                | 
                |     Parameters:
                | 
                |         oKeepModelSpace
                |             Legal values:
                |             TRUE : always keep the entire Model Space in its own sheet.
                |             FALSE : keep the entire Model Space in its own sheet but only if the automatic management detects that it's required. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ImportKeepModelSpace

    @property
    def import_map_layer_on2_dl(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportMapLayerOn2DL() As boolean (Read Only)
                | 
                |     Get the value of Map Layer On 2DL sheet option.
                | 
                |     Parameters:
                | 
                |         oMapLayerOn2DL
                |             Legal values:
                |             TRUE : always Map Layer On 2DL sheets.
                |             FALSE : No specific treatment on layer 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ImportMapLayerOn2DL

    @property
    def import_paper_spaces_in_background(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportPaperSpacesInBackground() As boolean (Read
                | Only)
                | 
                |     Get the value of the Paper Spaces in Background option.
                | 
                |     Parameters:
                | 
                |         oPaperSpacesInBackground
                |             Legal values:
                |             TRUE : All Paper Spaces entities are put into the corresponding Sheet's Background
                |             FALSE : All Paper Spaces entities are put into a view inside the corresponding Sheet's Working Views 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: bool
        """

        return self.dxf_setting_att.ImportPaperSpacesInBackground

    @property
    def import_scale_denominator(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportScaleDenominator() As double (Read Only)
                | 
                |     Get the denominator value of the scale factor. That value is only taken
                |     into account when the import unit is set to Scale Factor.
                | 
                |     Parameters:
                | 
                |         oScaleDen
                |             the denominator value of the scale factor. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: float
        """

        return self.dxf_setting_att.ImportScaleDenominator

    @property
    def import_scale_numerator(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportScaleNumerator() As double (Read Only)
                | 
                |     Get the numerator value of the scale factor. That value is only taken into
                |     account when the import unit is set to Scale Factor.
                | 
                |     Parameters:
                | 
                |         oScaleNum
                |             the numerator value of the scale factor. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: float
        """

        return self.dxf_setting_att.ImportScaleNumerator

    @property
    def import_unit(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImportUnit() As CatDxfImportUnitEnum (Read Only)
                | 
                |     Get the import unit.
                | 
                |     Parameters:
                | 
                |         oUnit
                |             Legal values: An available value of the enum CatDxfImportUnitEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :return: enum cat_dxf_import_unit_enum
        :rtype: int
        """

        return self.dxf_setting_att.ImportUnit

    def get_export_blocks_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportBlocksInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Blocks
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportBlocksInfo(io_admin_level, io_locked)

    def get_export_dimensions_as_dimensions_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportDimensionsAsDimensionsInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Dimensions As Dimensions
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportDimensionsAsDimensionsInfo(io_admin_level, io_locked)

    def get_export_layer_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportLayerNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Layer Name
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportLayerNameInfo(io_admin_level, io_locked)

    def get_export_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Mode
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportModeInfo(io_admin_level, io_locked)

    def get_export_sheets_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportSheetsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Exported Sheets
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportSheetsInfo(io_admin_level, io_locked)

    def get_export_version_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportVersionInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Version
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportVersionInfo(io_admin_level, io_locked)

    def get_export_views_as_viewports_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetExportViewsAsViewportsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Export Views as Viewports
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetExportViewsAsViewportsInfo(io_admin_level, io_locked)

    def get_import_dft_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDftStandardInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Drafting standard
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportDftStandardInfo(io_admin_level, io_locked)

    def get_import_dimensions_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDimensionsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Import dimensions
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportDimensionsInfo(io_admin_level, io_locked)

    def get_import_dxf_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportDxfStandardInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DXF standard
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportDxfStandardInfo(io_admin_level, io_locked)

    def get_import_end_points_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportEndPointsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Create End Points
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportEndPointsInfo(io_admin_level, io_locked)

    def get_import_keep_model_space_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportKeepModelSpaceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Keep Model Space
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportKeepModelSpaceInfo(io_admin_level, io_locked)

    def get_import_map_layer_on2_dl_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportMapLayerOn2DLInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for Map Layer On 2DL
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportMapLayerOn2DLInfo(io_admin_level, io_locked)

    def get_import_paper_spaces_in_background_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportPaperSpacesInBackgroundInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Paper Spaces in Background
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportPaperSpacesInBackgroundInfo(io_admin_level, io_locked)

    def get_import_scale_denominator_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportScaleDenominatorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the scale factor's denominator value
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportScaleDenominatorInfo(io_admin_level, io_locked)

    def get_import_scale_numerator_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportScaleNumeratorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the scale factor's numerator value
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportScaleNumeratorInfo(io_admin_level, io_locked)

    def get_import_unit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImportUnitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the import unit
                |     option.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the option is locked, AdminLevel gives the administration level
                |             that imposes the value of the option.
                |             If the option is not locked, AdminLevel gives the administration
                |             level that will give the value of the option after a reset.
                |             
                |         ioLocked
                |             Indicates if the option has been locked. 
                |         oModified
                |             Indicates if the option has been explicitly modified or remain to
                |             the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dxf_setting_att.GetImportUnitInfo(io_admin_level, io_locked)

    def set_export_blocks_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportBlocksLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Blocks option if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportBlocksLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_blocks_lock'
        # # vba_code = """
        # # Public Function set_export_blocks_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportBlocksLock iLocked
        # #     set_export_blocks_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_dimensions_as_dimensions_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportDimensionsAsDimensionsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Dimensions As Dimensions option if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportDimensionsAsDimensionsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_dimensions_as_dimensions_lock'
        # # vba_code = """
        # # Public Function set_export_dimensions_as_dimensions_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportDimensionsAsDimensionsLock iLocked
        # #     set_export_dimensions_as_dimensions_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_layer_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportLayerNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Layer Name option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportLayerNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_layer_name_lock'
        # # vba_code = """
        # # Public Function set_export_layer_name_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportLayerNameLock iLocked
        # #     set_export_layer_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Mode option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_mode_lock'
        # # vba_code = """
        # # Public Function set_export_mode_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportModeLock iLocked
        # #     set_export_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_sheets_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportSheetsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Exported Sheets option if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportSheetsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_sheets_lock'
        # # vba_code = """
        # # Public Function set_export_sheets_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportSheetsLock iLocked
        # #     set_export_sheets_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_version_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportVersionLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Version option if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportVersionLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_version_lock'
        # # vba_code = """
        # # Public Function set_export_version_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportVersionLock iLocked
        # #     set_export_version_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_views_as_viewports_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetExportViewsAsViewportsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Export Views as Viewports option if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetExportViewsAsViewportsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_views_as_viewports_lock'
        # # vba_code = """
        # # Public Function set_export_views_as_viewports_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetExportViewsAsViewportsLock iLocked
        # #     set_export_views_as_viewports_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dft_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDftStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the Drafting standard option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportDftStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_dft_standard_lock'
        # # vba_code = """
        # # Public Function set_import_dft_standard_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportDftStandardLock iLocked
        # #     set_import_dft_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dimensions_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDimensionsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Import dimensions option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportDimensionsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_dimensions_lock'
        # # vba_code = """
        # # Public Function set_import_dimensions_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportDimensionsLock iLocked
        # #     set_import_dimensions_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dxf_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportDxfStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the DXF standard option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportDxfStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_dxf_standard_lock'
        # # vba_code = """
        # # Public Function set_import_dxf_standard_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportDxfStandardLock iLocked
        # #     set_import_dxf_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_end_points_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportEndPointsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Create End Points option if the operation is allowed
                |     in the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportEndPointsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_end_points_lock'
        # # vba_code = """
        # # Public Function set_import_end_points_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportEndPointsLock iLocked
        # #     set_import_end_points_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_keep_model_space_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportKeepModelSpaceLock(boolean iLocked)
                | 
                |     Locks or unlocks the Keep Model Space option if the operation is allowed in
                |     the current administrated environment. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportKeepModelSpaceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_keep_model_space_lock'
        # # vba_code = """
        # # Public Function set_import_keep_model_space_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportKeepModelSpaceLock iLocked
        # #     set_import_keep_model_space_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_map_layer_on2_dl_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportMapLayerOn2DLLock(boolean iLocked)
                | 
                |     Locks or unlocks Map on Layer2DL option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportMapLayerOn2DLLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_map_layer_on2_dl_lock'
        # # vba_code = """
        # # Public Function set_import_map_layer_on2_dl_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportMapLayerOn2DLLock iLocked
        # #     set_import_map_layer_on2_dl_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_paper_spaces_in_background_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportPaperSpacesInBackgroundLock(boolean iLocked)
                | 
                |     Locks or unlocks the Paper Spaces in Background option if the operation is
                |     allowed in the current administrated environment. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportPaperSpacesInBackgroundLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_paper_spaces_in_background_lock'
        # # vba_code = """
        # # Public Function set_import_paper_spaces_in_background_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportPaperSpacesInBackgroundLock iLocked
        # #     set_import_paper_spaces_in_background_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_scale_denominator_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportScaleDenominatorLock(boolean iLocked)
                | 
                |     Locks or unlocks the scale factor's denominator value option if the
                |     operation is allowed in the current administrated environment. In user mode
                |     this method will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportScaleDenominatorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_scale_denominator_lock'
        # # vba_code = """
        # # Public Function set_import_scale_denominator_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportScaleDenominatorLock iLocked
        # #     set_import_scale_denominator_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_scale_numerator_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportScaleNumeratorLock(boolean iLocked)
                | 
                |     Locks or unlocks the scale factor's numerator value option if the operation
                |     is allowed in the current administrated environment. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportScaleNumeratorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_scale_numerator_lock'
        # # vba_code = """
        # # Public Function set_import_scale_numerator_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportScaleNumeratorLock iLocked
        # #     set_import_scale_numerator_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_unit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImportUnitLock(boolean iLocked)
                | 
                |     Locks or unlocks the import unit option if the operation is allowed in the
                |     current administrated environment. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE: to lock the option.
                |             FALSE: to unlock the option. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.dxf_setting_att.SetImportUnitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_unit_lock'
        # # vba_code = """
        # # Public Function set_import_unit_lock(dxf_setting_att)
        # #     Dim iLocked (2)
        # #     dxf_setting_att.SetImportUnitLock iLocked
        # #     set_import_unit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_blocks(self, i_export_blocks: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportBlocks(CatDxfExportBlocksEnum iExportBlocks)
                | 
                |     Set the value of the Export Layer Name option. That value is only taken
                |     into account when the export mode is set to Semantic.
                | 
                |     Parameters:
                | 
                |         iExportBlocks
                |             Legal values: An available value of the enum
                |             CatDxfExportBlocksEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_export_blocks: enum cat_dxf_export_blocks_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportBlocks(i_export_blocks)

    def set_export_dimensions_as_dimensions(self, i_export_dimension: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportDimensionsAsDimensions(boolean
                | iExportDimension)
                | 
                |     Set the value of the Export Dimensions As Dimensions option. That value is
                |     only taken into account when the export mode is set to
                |     Semantic.
                | 
                |     Parameters:
                | 
                |         iExportDimension
                |             Legal values:
                |             TRUE : Export dimensions as dimensions.
                |             FALSE : Export dimensions as graphical block. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_export_dimension:
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportDimensionsAsDimensions(i_export_dimension)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_dimensions_as_dimensions'
        # # vba_code = """
        # # Public Function set_export_dimensions_as_dimensions(dxf_setting_att)
        # #     Dim iExportDimension (2)
        # #     dxf_setting_att.set_ExportDimensionsAsDimensions iExportDimension
        # #     set_export_dimensions_as_dimensions = iExportDimension
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_layer_name(self, i_export_layer_name: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportLayerName(boolean iExportLayerName)
                | 
                |     Set the value of the Export Layer Name option. That value is only taken
                |     into account when the export mode is set to Semantic.
                | 
                |     Parameters:
                | 
                |         iExportLayerName
                |             Legal values:
                |             TRUE : Export Layer Name.
                |             FALSE : Export Layer Number. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_export_layer_name:
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportLayerName(i_export_layer_name)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_layer_name'
        # # vba_code = """
        # # Public Function set_export_layer_name(dxf_setting_att)
        # #     Dim iExportLayerName (2)
        # #     dxf_setting_att.set_ExportLayerName iExportLayerName
        # #     set_export_layer_name = iExportLayerName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_export_mode(self, i_mode: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportMode(CatDxfExportModeEnum iMode)
                | 
                |     Set the Export Mode option value.
                | 
                |     Parameters:
                | 
                |         iMode
                |             Legal values: An available value of the enum CatDxfExportModeEnum.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_mode: enum cat_dxf_export_mode_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportMode(i_mode)

    def set_export_sheets(self, i_sheets: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportSheets(CatDxfExportSheetsEnum iSheets)
                | 
                |     set the Exported Sheets option value.
                | 
                |     Parameters:
                | 
                |         iSheets
                |             Legal values: An available value of the enum
                |             CatDxfExportSheetsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_sheets: enum cat_dxf_export_sheets_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportSheets(i_sheets)

    def set_export_version(self, i_version: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportVersion(CatDxfExportVersionEnum iVersion)
                | 
                |     Set the Export Version option value.
                | 
                |     Parameters:
                | 
                |         iVersion
                |             Legal values: An available value of the enum
                |             CatDxfExportVersionEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_version:enum cat_dxf_export_version_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportVersion(i_version)

    def set_export_views_as_viewports(self, i_views_as_viewports: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ExportViewsAsViewports(boolean iViewsAsViewports)
                | 
                |     Set the value of the Export Views as Viewports option. That value is only
                |     taken into account when the export mode is set to
                |     Semantic.
                | 
                |     Parameters:
                | 
                |         iViewsAsViewports
                |             Legal values:
                |             TRUE : Enable the export of views as Viewports.
                |             FALSE : Disable the export of views as Viewports. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_views_as_viewports:
        :rtype: None
        """
        return self.dxf_setting_att.set_ExportViewsAsViewports(i_views_as_viewports)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_export_views_as_viewports'
        # # vba_code = """
        # # Public Function set_export_views_as_viewports(dxf_setting_att)
        # #     Dim iViewsAsViewports (2)
        # #     dxf_setting_att.set_ExportViewsAsViewports iViewsAsViewports
        # #     set_export_views_as_viewports = iViewsAsViewports
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_dft_standard(self, i_dft_standard: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDftStandard(CATBSTR iDftStandard)
                | 
                |     Set the name of the Drafting standard, which define the standard of the
                |     resulting CATDrawing file.
                | 
                |     Parameters:
                | 
                |         iDftStandard
                |             the CATBSTR corresponding to the Drafting standard.
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dft_standard:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportDftStandard(i_dft_standard)

    def set_import_dimensions(self, i_dimensions: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDimensions(CatDxfImportDimensionsEnum
                | iDimensions)
                | 
                |     Set the Import dimensions option value.
                | 
                |     Parameters:
                | 
                |         iDimensions
                |             Legal values: An available value of the enum
                |             CatDxfImportDimensionsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_dimensions: enum cat_dxf_import_dimensions_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportDimensions(i_dimensions)

    def set_import_dxf_standard(self, i_dxf_standard: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportDxfStandard(CATBSTR iDxfStandard)
                | 
                |     Set the name of the Dxf standard, which define the different mapping used
                |     at import.
                | 
                |     Parameters:
                | 
                |         iDxfStandard
                |             the CATBSTR corresponding to the Dxf standard. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str i_dxf_standard:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportDxfStandard(i_dxf_standard)

    def set_import_end_points(self, i_end_points: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportEndPoints(CatDxfImportCreateEndPointsEnum
                | iEndPoints)
                | 
                |     Set the Create End Points option value.
                | 
                |     Parameters:
                | 
                |         iEndPoints
                |             Legal values: An available value of the enum
                |             CatDxfImportCreateEndPointsEnum. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_end_points: enum cat_dxf_import_create_end_points_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportEndPoints(i_end_points)

    def set_import_keep_model_space(self, i_keep_model_space: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportKeepModelSpace(boolean iKeepModelSpace)
                | 
                |     Set the value of the Keep Model Space option.
                | 
                |     Parameters:
                | 
                |         iKeepModelSpace
                |             Legal values:
                |             TRUE : always keep the entire Model Space in its own sheet.
                |             FALSE : keep the entire Model Space in its own sheet but only if the automatic management detects that it's required. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_keep_model_space:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportKeepModelSpace(i_keep_model_space)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_keep_model_space'
        # # vba_code = """
        # # Public Function set_import_keep_model_space(dxf_setting_att)
        # #     Dim iKeepModelSpace (2)
        # #     dxf_setting_att.set_ImportKeepModelSpace iKeepModelSpace
        # #     set_import_keep_model_space = iKeepModelSpace
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_map_layer_on2_dl(self, i_map_layer_on2_dl: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportMapLayerOn2DL(boolean iMapLayerOn2DL)
                | 
                |     Set the value of Map Layer On 2DL sheet option.
                | 
                |     Parameters:
                | 
                |         iMapLayerOn2DL
                |             Legal values:
                |             TRUE : always Map Layer On 2DL sheets.
                |             FALSE : No specific treatment on layer 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_map_layer_on2_dl:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportMapLayerOn2DL(i_map_layer_on2_dl)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_map_layer_on2_dl'
        # # vba_code = """
        # # Public Function set_import_map_layer_on2_dl(dxf_setting_att)
        # #     Dim iMapLayerOn2DL (2)
        # #     dxf_setting_att.set_ImportMapLayerOn2DL iMapLayerOn2DL
        # #     set_import_map_layer_on2_dl = iMapLayerOn2DL
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_paper_spaces_in_background(self, i_paper_spaces_in_background: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportPaperSpacesInBackground(boolean
                | iPaperSpacesInBackground)
                | 
                |     Set the value of the Paper Spaces in Background option.
                | 
                |     Parameters:
                | 
                |         iPaperSpacesInBackground
                |             Legal values:
                |             TRUE : All Paper Spaces entities are put into the corresponding Sheet's Background
                |             FALSE : All Paper Spaces entities are put into a view inside the corresponding Sheet's Working Views 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_paper_spaces_in_background:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportPaperSpacesInBackground(i_paper_spaces_in_background)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_import_paper_spaces_in_background'
        # # vba_code = """
        # # Public Function set_import_paper_spaces_in_background(dxf_setting_att)
        # #     Dim iPaperSpacesInBackground (2)
        # #     dxf_setting_att.set_ImportPaperSpacesInBackground iPaperSpacesInBackground
        # #     set_import_paper_spaces_in_background = iPaperSpacesInBackground
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_import_scale_denominator(self, i_scale_den: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportScaleDenominator(double iScaleDen)
                | 
                |     Get the denominator value of the scale factor. That value is only taken
                |     into account when the import unit is set to Scale Factor.
                | 
                |     Parameters:
                | 
                |         iScaleDen
                |             the denominator value of the scale factor, which is supposed to be
                |             not null. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param float i_scale_den:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportScaleDenominator(i_scale_den)

    def set_import_scale_numerator(self, i_scale_num: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportScaleNumerator(double iScaleNum)
                | 
                |     Set the numerator value of the scale factor. That value is only taken into
                |     account when the import unit is set to Scale Factor.
                | 
                |     Parameters:
                | 
                |         iScaleNum
                |             the numerator value of the scale factor. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param float i_scale_num:
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportScaleNumerator(i_scale_num)

    def set_import_unit(self, i_unit: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub set_ImportUnit(CatDxfImportUnitEnum iUnit)
                | 
                |     Set the import unit.
                | 
                |     Parameters:
                | 
                |         iUnit
                |             Legal values: An available value of the enum CatDxfImportUnitEnum
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param int i_unit: enum cat_dxf_import_unit_enum
        :rtype: None
        """
        return self.dxf_setting_att.set_ImportUnit(i_unit)

    def __repr__(self):
        return f'DxfSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity


class DelayAct(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DelayAct
                | 
                | Interface representing a DelayAct.
                | 
                | Role: This interface is used to retrieve/assign the value of motion
                | targets/attrs for the move home activity.
                | The following code snippet can be used to obtain a MoveHomeAct from a selected
                | Activity
                | 
                |    Dim oSelectAct As Activity
                |    Set oSelectAct = CATIA.ActiveDocument.Selection.FindObject("CATIAActivity")
                |    Dim objMoveAct As DelayAct
                |    Set objMoveAct = oSelectAct.GetTechnologicalObject("DelayAct")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.delay_act = com_object

    @property
    def delay(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Delay() As double
                | 
                |     This property returns and sets the delay value of the
                |     activity.
                | 
                |     Example:
                |
                |            Dim objDelayAct As DelayAct
                |            .......
                |            Dim  delay as Double
                |            delay=objDelayAct.Delay
                |            delay  = 30
                |            objDelayAct.Delay=delay

        :rtype: float
        """

        return self.delay_act.Delay

    @delay.setter
    def delay(self, value: float):
        """
        :param float value:
        """

        self.delay_act.Delay = value

    def __repr__(self):
        return f'DelayAct(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.relation import Relation
from pycatia.system_interfaces.any_object import AnyObject


class Parameter(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Parameter
                | 
                | Represents the parameter.
                | It can be computed from a relation: formula, program, or check. It is an
                | abstract object which is not intended to be created as such, but from which the
                | integer, bolean, real, and string parameters derive. Here is an example to
                | create one:
                | 
                | 	Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim density As RealParam
                |  Set density = part1.Part.Parameters.CreateReal("density", 2.5)
                |  
                | 
                | See also:
                |     IntParam, BoolParam, RealParam, StrParam, Formula, Rule, Check
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.parameter = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Comment() As CATBSTR
                | 
                |     Returns or sets the parameter object comment.

        :rtype: str
        """

        return self.parameter.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.parameter.Comment = value

    @property
    def context(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Context() As AnyObject (Read Only)
                | 
                |     Returns the context of the parameter : a part, a product, a drafting, a process, depending where
                |     the parameter is.

        :rtype: AnyObject
        """

        return AnyObject(self.parameter.Context)

    @property
    def hidden(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Hidden() As boolean
                | 
                |     Returns or sets whether the parameter is hidden or should be hidden or not.

        :rtype: bool
        """

        return self.parameter.Hidden

    @hidden.setter
    def hidden(self, value: bool):
        """
        :param bool value:
        """

        self.parameter.Hidden = value

    @property
    def is_true_parameter(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property IsTrueParameter() As boolean (Read Only)
                | 
                |     Returns a boolean saying if the parameter is a true one (real, dimension,
                |     string, etc.) or a geometrical one (isolated points, curves, surfaces).

        :rtype: bool
        """

        return self.parameter.IsTrueParameter

    @property
    def optional_relation(self) -> Relation:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property OptionalRelation() As Relation (Read Only)
                | 
                |     Returns the relation that can be used to compute the parameter. As this
                |     relation might not exist, NULL may be returned, so a test is
                |     required.
                | 
                |     Example:
                |         This example checks if there is a relation to compute the param1
                |         parameter, and if no relation exists, displays a message
                |         box:
                | 
                |          Set param1_rel = param1.OptionalRelation
                |          If param1_rel is Nothing Then
                |               MsgBox "No relation to compute param1"
                |          End If

        :rtype: Relation
        """

        return Relation(self.parameter.OptionalRelation)

    @property
    def read_only(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ReadOnly() As boolean (Read Only)
                | 
                |     Returns whether the parameter can be modified.
                | 
                |     Example:
                |         This example checks if the param1 parameter can be modified, and if it
                |         cannot, displays a message box:
                | 
                |          If ( param1.ReadOnly ) Then
                |               MsgBox "No way to change param1"
                |          End If

        :rtype: bool
        """

        return self.parameter.ReadOnly

    @property
    def renamed(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Renamed() As boolean (Read Only)
                | 
                |     Returns a boolean saying if the parameter is a renamed parameter or not.

        :rtype: bool
        """

        return self.parameter.Renamed

    @property
    def user_access_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property UserAccessMode() As long (Read Only)
                | 
                |     Returns the user access mode of the parameter. 
                | 
                | 0
                |     Read only parameter (cannot be destroyed). 
                | 1
                |     Read/write parameter (cannot be destroyed). 
                | 2
                |     User parameter (can be read, written and destroyed).
                |     Methods
                | 
                | o Sub Rename(CATBSTR iName)
                | 
                |     Renames the parameter.
                | 
                |     Parameters:
                | 
                |         iName
                |             The new name of the parameter. If iName contains "Local:" prefix
                |             the rename will affect the local name. If not, it will affect the global name.
                |             
                | 
                |     Example:
                |         This example renames the param1 parameter to
                |         PartSeatbodyMinimumThickness:
                | 
                |          Call param1.Rename("PartSeatbodyMinimumThickness")
                |          
                | 
                | o Sub ValuateFromString(CATBSTR iValue)
                | 
                |     Valuates a parameter using a string as input. The string depends on
                |     parameter nature :
                | 
                |     "True" or "False" for Boolean
                | 
                |     a numerical value for Integer or Real
                | 
                |     a numerical value with or without a unit for Dimension
                | 
                |     Parameters:
                | 
                |         iValue
                |             The value to assign to the dimension parameter 
                | 
                |     Example:
                |         This example sets the value of the existing dimension parameter to a
                |         new value:
                | 
                |          dimension.ValuateFromString("300mm");
                |          
                | 
                | o Func ValueAsString() As CATBSTR
                | 
                |     Returns the value of the parameter as a string.
                | 
                | Example:
                |     This example gets the value of the existing dimension parameter and shows
                |     it in a message box
                | 
                |      Dim str
                |      str = dimension.ValueAsString;
                |      MessageBox str
                |      
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :rtype: int
        """

        return self.parameter.UserAccessMode

    def rename(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Rename(CATBSTR iName)
                |
                |     Renames the parameter.
                |
                |     Parameters:
                |
                |         iName
                |             The new name of the parameter. If iName contains "Local:" prefix
                |             the rename will affect the local name. If not, it will affect the global name.
                |
                |
                |     Example:
                |         This example renames the param1 parameter to
                |         PartSeatbodyMinimumThickness:
                |
                |          Call param1.Rename("PartSeatbodyMinimumThickness")

        :param str i_name:
        :rtype: None
        """
        return self.parameter.Rename(i_name)

    def valuate_from_string(self, i_value: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ValuateFromString(CATBSTR iValue)
                |
                |     Valuates a parameter using a string as input. The string depends on
                |     parameter nature :
                |
                |     "True" or "False" for Boolean
                |
                |     a numerical value for Integer or Real
                |
                |     a numerical value with or without a unit for Dimension
                |
                |     Parameters:
                |
                |         iValue
                |             The value to assign to the dimension parameter
                |
                |     Example:
                |         This example sets the value of the existing dimension parameter to a
                |         new value:
                |
                |          dimension.ValuateFromString("300mm");

        :param str i_value:
        :rtype: None
        """
        return self.parameter.ValuateFromString(i_value)

    def value_as_string(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ValueAsString() As CATBSTR
                |
                |     Returns the value of the parameter as a string.
                |
                | Example:
                |     This example gets the value of the existing dimension parameter and shows
                |     it in a message box
                |
                |      Dim str
                |      str = dimension.ValueAsString;
                |      MessageBox str
                |
                |
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :rtype: str
        """
        return self.parameter.ValueAsString()

    def __repr__(self):
        return f'Parameter(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class BehaviorSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         BehaviorSettingAtt
                | 
                | Enables attribute access to BKT options.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.behavior_setting_att = com_object

    @property
    def bkt_access_rights(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BKTAccessRights() As long
                | 
                |     Returns or sets the BKTAccessRights parameter.
                | 
                |     Parameters:
                | 
                |         iBKTAccessRights
                |             oBKTAccessRights Legal values:
                |             0 : User mode
                |             1: Administrator mode
                |             2: Expert mode 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.behavior_setting_att.BKTAccessRights

    @bkt_access_rights.setter
    def bkt_access_rights(self, value: int):
        """
        :param int value:
        """

        self.behavior_setting_att.BKTAccessRights = value

    @property
    def bkt_behavior_operation_message(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BKTBehaviorOperationMessage() As long
                | 
                |     Returns or sets the BKTBehaviorOperationMessage parameter.
                | 
                |     Parameters:
                | 
                |         iBKTBehaviorOperationMessage
                |             oBKTBehaviorOperationMessage Legal values:
                |             0 : No operation messages
                |             1: with operation messages 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.behavior_setting_att.BKTBehaviorOperationMessage

    @bkt_behavior_operation_message.setter
    def bkt_behavior_operation_message(self, value: int):
        """
        :param int value:
        """

        self.behavior_setting_att.BKTBehaviorOperationMessage = value

    @property
    def bkt_specification_tree(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property BKTSpecificationTree() As long
                | 
                |     Returns or sets the BKTSpecificationTree parameter.
                | 
                |     Parameters:
                | 
                |         iBKTSpecificationTree
                |             oBKTSpecificationTree Legal values:
                |             0 : hides behaviors variables
                |             1: displays behaviors variables 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.behavior_setting_att.BKTSpecificationTree

    @bkt_specification_tree.setter
    def bkt_specification_tree(self, value: int):
        """
        :param int value:
        """

        self.behavior_setting_att.BKTSpecificationTree = value

    def get_bkt_access_rights_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBKTAccessRightsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BKTAccessRights
                |     parameter.
                |     Role:Retrieves the state of the BKTAccessRights parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.behavior_setting_att.GetBKTAccessRightsInfo(io_admin_level, io_locked)

    def get_bkt_behavior_operation_message_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBKTBehaviorOperationMessageInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BKTBehaviorOperationMessage
                |     parameter.
                |     Role:Retrieves the state of the BKTBehaviorOperationMessage parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.behavior_setting_att.GetBKTBehaviorOperationMessageInfo(io_admin_level, io_locked)

    def get_bkt_specification_tree_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBKTSpecificationTreeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the BKTSpecificationTree
                |     parameter.
                |     Role:Retrieves the state of the BKTSpecificationTree parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.behavior_setting_att.GetBKTSpecificationTreeInfo(io_admin_level, io_locked)

    def set_bkt_access_rights_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBKTAccessRightsLock(boolean iLocked)
                | 
                |     Locks or unlocks the BKTAccessRights parameter.
                |     Role:Locks or unlocks the BKTAccessRights parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.behavior_setting_att.SetBKTAccessRightsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_bkt_access_rights_lock'
        # # vba_code = """
        # # Public Function set_bkt_access_rights_lock(behavior_setting_att)
        # #     Dim iLocked (2)
        # #     behavior_setting_att.SetBKTAccessRightsLock iLocked
        # #     set_bkt_access_rights_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_bkt_behavior_operation_message_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBKTBehaviorOperationMessageLock(boolean iLocked)
                | 
                |     Locks or unlocks the BKTBehaviorOperationMessage
                |     parameter.
                |     Role:Locks or unlocks the BKTBehaviorOperationMessage parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.behavior_setting_att.SetBKTBehaviorOperationMessageLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_bkt_behavior_operation_message_lock'
        # # vba_code = """
        # # Public Function set_bkt_behavior_operation_message_lock(behavior_setting_att)
        # #     Dim iLocked (2)
        # #     behavior_setting_att.SetBKTBehaviorOperationMessageLock iLocked
        # #     set_bkt_behavior_operation_message_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_bkt_specification_tree_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBKTSpecificationTreeLock(boolean iLocked)
                | 
                |     Locks or unlocks the BKTSpecificationTree parameter.
                |     Role:Locks or unlocks the BKTSpecificationTree parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.behavior_setting_att.SetBKTSpecificationTreeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_bkt_specification_tree_lock'
        # # vba_code = """
        # # Public Function set_bkt_specification_tree_lock(behavior_setting_att)
        # #     Dim iLocked (2)
        # #     behavior_setting_att.SetBKTSpecificationTreeLock iLocked
        # #     set_bkt_specification_tree_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'BehaviorSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.behavior_interfaces.behavior import Behavior
from pycatia.system_interfaces.any_object import AnyObject


class BehaviorVBScript(Behavior):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CATBehaviorInterfaces.Behavior
                |                         BehaviorVBScript
                | 
                | Represents the VBScript behavior.
                | Role: The VB script behavior is designed to run a VBScript (or catvbs files) or
                | to reference a VBA project. This interface derives from Behavior and enables
                | the manipulation of the internal variables of the VBScript
                | behavior.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.behavior_vb_script = com_object

    def cancel(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Cancel()
                | 
                |     Inform Client VB has Failed & Has Not operated.
                | 
                |     Example:
                | 
                |     Deprecated:
                |         V5R15 (Not needed)

        :rtype: None
        """
        return self.behavior_vb_script.Cancel()

    def done(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Done()
                | 
                |     Inform Client VB has Successfully Finished.
                | 
                |     Example:
                | 
                |     Deprecated:
                |         V5R15 (Not needed)

        :rtype: None
        """
        return self.behavior_vb_script.Done()

    def get_internal(self, p_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInternal(CATBSTR pName) As AnyObject
                | 
                |     Returns one available io of the behavior. The behavior has to be in
                |     executing mode, otherwise it fails
                | 
                |     Example:
                |         This example retrieves in BehParameter the internal parameter
                |         CATIAReference XXX currently managed by a Behavior
                |         Beh.
                | 
                |          Dim BehParameter as Parameter
                |          Set BehParameter = Beh.GetInternal("XXX")

        :param str p_name:
        :rtype: AnyObject
        """
        return AnyObject(self.behavior_vb_script.GetInternal(p_name))

    def put_internal(self, p_name: str, o_value: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutInternal(CATBSTR pName,
                | AnyObject oValue)
                | 
                |     provide output of one available io of the behavior. The behavior has to be
                |     in executing mode, otherwise it fails
                | 
                |     Example:
                |         This example assign the BehParameter containing a CATIAReference to the
                |         internal parameter XXX currently managed by a Behavior
                |         Beh.
                | 
                |          Dim BehPower as Parameter
                |          Beh.PutInternal "XXX", BehParameter

        :param str p_name:
        :param AnyObject o_value:
        :rtype: None
        """
        return self.behavior_vb_script.PutInternal(p_name, o_value.com_object)

    def start(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Start()
                | 
                |     Inform Client VB has Started.
                | 
                |     Example:
                | 
                |     Deprecated:
                |         V5R15 (Not needed)

        :rtype: None
        """
        return self.behavior_vb_script.Start()

    def suspend(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Suspend()
                | 
                |     Inform Client VB has not completly finished the task and has to be called
                |     later on
                | 
                |     Example:
                | 
                |     Deprecated:
                |         V5R15 (Not needed)

        :rtype: None
        """
        return self.behavior_vb_script.Suspend()

    def test_internal(self, p_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TestInternal(CATBSTR pName) As long
                | 
                |     Test for one available output of the behavior. The behavior has to be in
                |     executing mode, otherwise it fails
                | 
                |     Example:
                |         This example test for the value existance of an internal parameter XXX
                |         that may contain or not a CATIAReference currently managed by a Behavior
                |         Beh.
                | 
                |          if (Beh.TestInternal("XXX"))

        :param str p_name:
        :rtype: int
        """
        return self.behavior_vb_script.TestInternal(p_name)

    def __repr__(self):
        return f'BehaviorVBScript(name="{self.name}")'



from pycatia.analysis_interfaces.analysis_document import AnalysisDocument
from pycatia.components_catalogs_interfaces.catalog_document import CatalogDocument
from pycatia.cat_mat_interfaces.material_document import MaterialDocument
from pycatia.dmaps_interfaces.process_document import ProcessDocument
from pycatia.drafting_interfaces.drawing_document import DrawingDocument
from pycatia.in_interfaces.document import Document
from pycatia.mec_mod_interfaces.part_document import PartDocument
from pycatia.product_structure_interfaces.product_document import ProductDocument
from pycatia.funct_system_interfaces.functional_document import FunctionalDocument


document_types = {
    'Analysis': {
        'extension': 'CATAnalysis',
        'type': AnalysisDocument,
    },
    'CatalogDocument': {
        'extension': 'catalog',
        'type': CatalogDocument,
    },
    'CATMaterial': {
        'extension': 'CATMaterial',
        'type': MaterialDocument,
    },
    'CATProcess': {
        'extension': 'CATProcess',
        'type': ProcessDocument,
    },
    'cgm': {
        'extension': 'cgm',
        'type': Document,
    },
    'Drawing': {
        'extension': 'CATDrawing',
        'type': DrawingDocument,
    },
    'FeatureDictionary': {
        'extension': 'CATfct',
        'type': Document
    },
    'gl': {
        'extension': 'gl',
        'type': Document,
    },
    'gl2': {
        'extension': 'gl2',
        'type': Document,
    },
    'hpgl': {
        'extension': 'hpgl',
        'type': Document
    },
    'FunctionalSystem': {
        'extension': 'CATSystem',
        'type': FunctionalDocument,
    },
    'Part': {
        'extension': 'CATPart',
        'type': PartDocument,
    },
    'Product': {
        'extension': 'CATProduct',
        'type': ProductDocument
    },
    'ProcessLibrary': {
        'extension': 'act',
        'type': ProcessDocument,
    },
    'Default': {
        'extension': None,
        'type': Document
    }
}
